@@ -1,5 +1,5 @@
 /* This file is part of Metaproxy.
-   Copyright (C) 2005-2010 Index Data
+   Copyright (C) 2005-2012 Index Data
 
 Metaproxy is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License as published by the Free
@@ -38,11 +38,13 @@ namespace metaproxy_1
         RouterFleXML(std::string xmlconf, metaproxy_1::FactoryFilter &factory,
             bool test_only);
         RouterFleXML(xmlDocPtr doc, metaproxy_1::FactoryFilter &factory,
-            bool test_only);
+                     bool test_only, const char *file_include_path);
         
         ~RouterFleXML();
 
         virtual RoutePos *createpos() const;
+        void start();
+        void stop();
     private:
         boost::scoped_ptr<Rep> m_p;
     };
